@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -16,12 +16,6 @@
 # Public License, GNU Lesser General Public License, Expat License, or
 # Apache License 2.0.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
-
 __all__ = ['Game']
 
 
@@ -110,6 +104,11 @@ class Game(object):
        specified in :data:`sge.image_directories` to use as the window
        icon.  If set to :const:`None`, the SGE chooses the icon.
 
+    .. attribute:: registered_classes
+
+       A list containing all classes which have been registered with
+       :meth:`sge.Game.register_class`.  (Read-only)
+
     .. attribute:: sprites
 
        A dictionary containing all loaded sprites, indexed by the
@@ -220,6 +219,16 @@ class Game(object):
         """Unpause the game."""
         # TODO
 
+    def register_class(self, cls):
+        """Register a class with the SGE.
+
+        Registered classes can be used to index objects by, e.g. for
+        :attr:`sge.Room.objects_by_class`.  A list of all currently
+        registered classes can be found in :attr:`registered_classes`.
+
+        """
+        # TODO
+
     def event_game_start(self):
         """Game start event.
 
@@ -313,13 +322,16 @@ class Game(object):
         """
         pass
 
-    def event_joystick_axis_move(self, joystick, axis, value):
+    def event_joystick_axis_move(self, name, ID, axis, value):
         """Joystick axis move event.
 
         Called when an axis on a joystick changes position.
 
         Arguments:
 
+        - ``name`` -- The name of the joystick.
+        - ``ID`` -- The number of the joystick, where ``0`` is the first
+          joystick.
         - ``value`` -- The tilt of the axis as a float from ``-1`` to
           ``1``, where ``0`` is centered, ``-1`` is all the way to the
           left or up, and ``1`` is all the way to the right or down.
@@ -330,7 +342,7 @@ class Game(object):
         """
         pass
 
-    def event_joystick_hat_move(self, joystick, hat, x, y):
+    def event_joystick_hat_move(self, name, ID, hat, x, y):
         """Joystick HAT move event.
 
         Called when a HAT switch (also called the POV hat, POV switch,
@@ -338,6 +350,9 @@ class Game(object):
 
         Arguments:
 
+        - ``name`` -- The name of the joystick.
+        - ``ID`` -- The number of the joystick, where ``0`` is the first
+          joystick.
         - ``x`` -- The horizontal position of the HAT, where ``0`` is
           centered, ``-1`` is left, and ``1`` is right.
         - ``y`` -- The vertical position of the HAT, where ``0`` is
@@ -349,15 +364,16 @@ class Game(object):
         """
         pass
 
-    def event_joystick_trackball_move(self, joystick, ball, x, y):
+    def event_joystick_trackball_move(self, name, ID, ball, x, y):
         """Joystick trackball move event.
 
         Called when a trackball on a joystick moves.
 
         Arguments:
 
-        - ``joystick`` -- The number of the joystick, where ``0`` is the
-          first joystick.
+        - ``name`` -- The name of the joystick.
+        - ``ID`` -- The number of the joystick, where ``0`` is the first
+          joystick.
         - ``ball`` -- The number of the trackball, where ``0`` is the
           first trackball on the joystick.
         - ``x`` -- The horizontal relative movement of the trackball.
@@ -366,22 +382,34 @@ class Game(object):
         """
         pass
 
-    def event_joystick_button_press(self, joystick, button):
+    def event_joystick_button_press(self, name, ID, button):
         """Joystick button press event.
 
         Called when a joystick button is pressed.
 
+        Arguments:
+
+        - ``name`` -- The name of the joystick.
+        - ``ID`` -- The number of the joystick, where ``0`` is the first
+          joystick.
+
         See the documentation for
         :func:`sge.get_joystick_button_pressed` for more information.
 
         """
         pass
 
-    def event_joystick_button_release(self, joystick, button):
+    def event_joystick_button_release(self, name, ID, button):
         """Joystick button release event.
 
         Called when a joystick button is pressed.
 
+        Arguments:
+
+        - ``name`` -- The name of the joystick.
+        - ``ID`` -- The number of the joystick, where ``0`` is the first
+          joystick.
+
         See the documentation for
         :func:`sge.get_joystick_button_pressed` for more information.
 
@@ -560,7 +588,7 @@ class Game(object):
         """
         pass
 
-    def event_paused_joystick_axis_move(self, joystick, axis, value):
+    def event_paused_joystick_axis_move(self, name, ID, axis, value):
         """Joystick axis move event when paused.
 
         See the documentation for
@@ -569,7 +597,7 @@ class Game(object):
         """
         pass
 
-    def event_paused_joystick_hat_move(self, joystick, hat, x, y):
+    def event_paused_joystick_hat_move(self, name, ID, hat, x, y):
         """Joystick HAT move event when paused.
 
         See the documentation for
@@ -578,7 +606,7 @@ class Game(object):
         """
         pass
 
-    def event_paused_joystick_trackball_move(self, joystick, ball, x, y):
+    def event_paused_joystick_trackball_move(self, name, ID, ball, x, y):
         """Joystick trackball move event when paused.
 
         See the documentation for
@@ -588,7 +616,7 @@ class Game(object):
         """
         pass
 
-    def event_paused_joystick_button_press(self, joystick, button):
+    def event_paused_joystick_button_press(self, name, ID, button):
         """Joystick button press event when paused.
 
         See the documentation for
@@ -598,7 +626,7 @@ class Game(object):
         """
         pass
 
-    def event_paused_joystick_button_release(self, joystick, button):
+    def event_paused_joystick_button_release(self, name, ID, button):
         """Joystick button release event when paused.
 
         See the documentation for
